# bijoe - BI dashboard
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import glob
import json

from django.conf import settings
from django.db import connection
from django.utils.translation import ugettext as _
try:
    from functools import lru_cache
except ImportError:
    from django.utils.lru_cache import lru_cache


from .schemas import Warehouse


def get_warehouses_paths():
    for pattern in settings.BIJOE_SCHEMAS:
        for path in glob.glob(pattern):
            yield path
    if hasattr(connection, 'tenant'):
        pattern = os.path.join(connection.tenant.get_directory(), 'schemas', '*.model')
        for path in glob.glob(pattern):
            yield path


@lru_cache()
def get_warehouses_by_paths(paths):
    warehouses = []
    for path in paths:
        d = json.load(open(path))
        d['path'] = path
        warehouses.append(Warehouse.from_json(d))
    return warehouses


def get_warehouses():
    paths = frozenset(get_warehouses_paths())
    return get_warehouses_by_paths(paths)


def human_join(l):
    if not l:
        return ''
    if len(l) == 1:
        return l[0]
    if len(l) > 2:
        l = u', '.join(l[:-1]), l[-1]
    return _(u'{0} and {1}').format(l[0], l[1])
